# PyToBF - Python to Brainfuck Transpiler
Desenvolvido por **MurilooPrDev**. 

Este é um transpilador sagrado que converte lógica Python (While, If/Else, Print) para a linguagem esotérica Brainfuck.

## Instalação
```bash
pip install pytobf-muriloopr
```

## Uso
```bash
pytobf script.py
```
